@@ -28,7 +28,6 @@
 #include <QStandardPaths>
 #include <KMessageBox>
 #include <KConfigDialog>
-#include <KNS3/DownloadDialog>
 
 #include <QDir>
 #include <QStringList>
@@ -49,9 +48,9 @@ NewGameWidget::NewGameWidget(NewGameSetup* newGameSetup, QWidget *parent) :
   
   QObject::connect(nextButton, &QAbstractButton::clicked, this, &NewGameWidget::slotOK );
   QObject::connect(cancelButton, &QAbstractButton::clicked, this, &NewGameWidget::slotCancel );
-  QObject::connect(skinCombo, SIGNAL(activated(int)), this, SLOT(slotSkinChanged(int)) );
-  QObject::connect(ghnsbutton, &QAbstractButton::clicked, this, &NewGameWidget::slotGHNS );
-  QObject::connect(tcpPortEntry,SIGNAL(valueChanged(int)),this, SLOT(slotTcpPortEdited(int)));
+  QObject::connect(skinCombo, &QComboBox::activated, this, &NewGameWidget::slotSkinChanged);
+  QObject::connect(ghnsbutton, &KNSWidgets::Button::dialogFinished, this, &NewGameWidget::slotGHNS );
+  QObject::connect(tcpPortEntry, &QSpinBox::valueChanged, this, &NewGameWidget::slotTcpPortEdited);
 }
 
 void NewGameWidget::init(const QString& skin, GameAutomaton::NetworkGameType netGameType)
@@ -68,11 +67,13 @@ void NewGameWidget::init(const QString& skin, GameAutomaton::NetworkGameType net
       tcpPortLabel->show();
       tcpPortEntry->show();
     }
+#if HAVE_JABBER_SUPPORT
     if (netGameType == GameAutomaton::Jabber)
     {
       tcpPortLabel->hide();
       tcpPortEntry->hide();
     }
+#endif
     m_newGameSetup->setNbNetworkPlayers(1);
     localPlayersNumberEntry->setValue(m_newGameSetup->nbNetworkPlayers());
   }
@@ -188,9 +189,6 @@ void NewGameWidget::slotGHNS()
   // {
   //   return;
   // }
-  qCDebug(KSIRK_LOG);
-  KNS3::DownloadDialog dialog(this);
-  dialog.exec();
   
   fillSkinsCombo();
 /*  KConfigDialog *dialog = new KConfigDialog(this, "settings", KsirkSettings::self());
